==> inferno-3.0.4.tgz: package/dist-es/DOM/constants.js <==
export const xlinkNS = 'http://www.w3.org/1999/xlink';
export const xmlNS = 'http://www.w3.org/XML/1998/namespace';
export const svgNS = 'http://www.w3.org/2000/svg';
export const strictProps = new Set();
strictProps.add('volume');
strictProps.add('defaultChecked');
export const booleanProps = new Set();
booleanProps.add('muted');
booleanProps.add('scoped');
booleanProps.add('loop');
booleanProps.add('open');
booleanProps.add('checked');
booleanProps.add('default');
booleanProps.add('capture');
booleanProps.add('disabled');
booleanProps.add('readOnly');
booleanProps.add('required');
booleanProps.add('autoplay');
booleanProps.add('controls');
booleanProps.add('seamless');
booleanProps.add('reversed');
booleanProps.add('allowfullscreen');
booleanProps.add('novalidate');
booleanProps.add('hidden');
booleanProps.add('autoFocus');
export const namespaces = new Map();
namespaces.set('xlink:href', xlinkNS);
namespaces.set('xlink:arcrole', xlinkNS);
namespaces.set('xlink:actuate', xlinkNS);
namespaces.set('xlink:show', xlinkNS);
namespaces.set('xlink:role', xlinkNS);
namespaces.set('xlink:title', xlinkNS);
namespaces.set('xlink:type', xlinkNS);
namespaces.set('xml:base', xmlNS);
namespaces.set('xml:lang', xmlNS);
namespaces.set('xml:space', xmlNS);
export const isUnitlessNumber = new Set();
isUnitlessNumber.add('animationIterationCount');
isUnitlessNumber.add('borderImageOutset');
isUnitlessNumber.add('borderImageSlice');
isUnitlessNumber.add('borderImageWidth');
isUnitlessNumber.add('boxFlex');
isUnitlessNumber.add('boxFlexGroup');
isUnitlessNumber.add('boxOrdinalGroup');
isUnitlessNumber.add('columnCount');
isUnitlessNumber.add('flex');
isUnitlessNumber.add('flexGrow');
isUnitlessNumber.add('flexPositive');
isUnitlessNumber.add('flexShrink');
isUnitlessNumber.add('flexNegative');
isUnitlessNumber.add('flexOrder');
isUnitlessNumber.add('gridRow');
isUnitlessNumber.add('gridColumn');
isUnitlessNumber.add('fontWeight');
isUnitlessNumber.add('lineClamp');
isUnitlessNumber.add('lineHeight');
isUnitlessNumber.add('opacity');
isUnitlessNumber.add('order');
isUnitlessNumber.add('orphans');
isUnitlessNumber.add('tabSize');
isUnitlessNumber.add('widows');
isUnitlessNumber.add('zIndex');
isUnitlessNumber.add('zoom');
isUnitlessNumber.add('fillOpacity');
isUnitlessNumber.add('floodOpacity');
isUnitlessNumber.add('stopOpacity');
isUnitlessNumber.add('strokeDasharray');
isUnitlessNumber.add('strokeDashoffset');
isUnitlessNumber.add('strokeMiterlimit');
isUnitlessNumber.add('strokeOpacity');
isUnitlessNumber.add('strokeWidth');
export const skipProps = new Set();
skipProps.add('children');
skipProps.add('childrenType');
skipProps.add('defaultValue');
skipProps.add('ref');
skipProps.add('key');
skipProps.add('selected');
skipProps.add('checked');
skipProps.add('multiple');
export const delegatedEvents = new Set();
delegatedEvents.add('onClick');
delegatedEvents.add('onMouseDown');
delegatedEvents.add('onMouseUp');
delegatedEvents.add('onMouseMove');
delegatedEvents.add('onSubmit');
delegatedEvents.add('onDblClick');
delegatedEvents.add('onKeyDown');
delegatedEvents.add('onKeyUp');
delegatedEvents.add('onKeyPress');

==> inferno-3.1.0.tgz: package/dist-es/DOM/constants.js <==
export const xlinkNS = 'http://www.w3.org/1999/xlink';
export const xmlNS = 'http://www.w3.org/XML/1998/namespace';
export const svgNS = 'http://www.w3.org/2000/svg';
export const strictProps = new Set();
strictProps.add('volume');
strictProps.add('defaultChecked');
export const booleanProps = new Set();
booleanProps.add('muted');
booleanProps.add('scoped');
booleanProps.add('loop');
booleanProps.add('open');
booleanProps.add('checked');
booleanProps.add('default');
booleanProps.add('capture');
booleanProps.add('disabled');
booleanProps.add('readOnly');
booleanProps.add('required');
booleanProps.add('autoplay');
booleanProps.add('controls');
booleanProps.add('seamless');
booleanProps.add('reversed');
booleanProps.add('allowfullscreen');
booleanProps.add('novalidate');
booleanProps.add('hidden');
booleanProps.add('autoFocus');
booleanProps.add('selected');
export const namespaces = new Map();
namespaces.set('xlink:href', xlinkNS);
namespaces.set('xlink:arcrole', xlinkNS);
namespaces.set('xlink:actuate', xlinkNS);
namespaces.set('xlink:show', xlinkNS);
namespaces.set('xlink:role', xlinkNS);
namespaces.set('xlink:title', xlinkNS);
namespaces.set('xlink:type', xlinkNS);
namespaces.set('xml:base', xmlNS);
namespaces.set('xml:lang', xmlNS);
namespaces.set('xml:space', xmlNS);
export const isUnitlessNumber = new Set();
isUnitlessNumber.add('animationIterationCount');
isUnitlessNumber.add('borderImageOutset');
isUnitlessNumber.add('borderImageSlice');
isUnitlessNumber.add('borderImageWidth');
isUnitlessNumber.add('boxFlex');
isUnitlessNumber.add('boxFlexGroup');
isUnitlessNumber.add('boxOrdinalGroup');
isUnitlessNumber.add('columnCount');
isUnitlessNumber.add('flex');
isUnitlessNumber.add('flexGrow');
isUnitlessNumber.add('flexPositive');
isUnitlessNumber.add('flexShrink');
isUnitlessNumber.add('flexNegative');
isUnitlessNumber.add('flexOrder');
isUnitlessNumber.add('gridRow');
isUnitlessNumber.add('gridColumn');
isUnitlessNumber.add('fontWeight');
isUnitlessNumber.add('lineClamp');
isUnitlessNumber.add('lineHeight');
isUnitlessNumber.add('opacity');
isUnitlessNumber.add('order');
isUnitlessNumber.add('orphans');
isUnitlessNumber.add('tabSize');
isUnitlessNumber.add('widows');
isUnitlessNumber.add('zIndex');
isUnitlessNumber.add('zoom');
isUnitlessNumber.add('fillOpacity');
isUnitlessNumber.add('floodOpacity');
isUnitlessNumber.add('stopOpacity');
isUnitlessNumber.add('strokeDasharray');
isUnitlessNumber.add('strokeDashoffset');
isUnitlessNumber.add('strokeMiterlimit');
isUnitlessNumber.add('strokeOpacity');
isUnitlessNumber.add('strokeWidth');
export const skipProps = new Set();
skipProps.add('children');
skipProps.add('childrenType');
skipProps.add('defaultValue');
skipProps.add('ref');
skipProps.add('key');
skipProps.add('checked');
skipProps.add('multiple');
export const delegatedEvents = new Set();
delegatedEvents.add('onClick');
delegatedEvents.add('onMouseDown');
delegatedEvents.add('onMouseUp');
delegatedEvents.add('onMouseMove');
delegatedEvents.add('onSubmit');
delegatedEvents.add('onDblClick');
delegatedEvents.add('onKeyDown');
delegatedEvents.add('onKeyUp');
delegatedEvents.add('onKeyPress');
